from distutils.version import LooseVersion

import matplotlib

MPL_VERSION = LooseVersion(matplotlib.__version__)

ROOT = "http://aplpy.github.io/aplpy-data/1.x/2016-09-21T08:12:02.530/"

if MPL_VERSION >= LooseVersion('1.5.0'):
    baseline_dir = ROOT + '/1.5.x/'
else:
    baseline_dir = ROOT + '/1.4.x/'



# Autogenerated by Astropy-affiliated package astropy_helpers's setup.py on 2015-03-07 13:02:20.399360
from __future__ import unicode_literals
import datetime

version = "1.0.1"
githash = "483a89fe8d8bbacd52e5831e3897680ff9e23966"


major = 1
minor = 0
bugfix = 1

release = True
timestamp = datetime.datetime(2015, 3, 7, 13, 2, 20, 399360)
debug = False

try:
    from ._compiler import compiler
except ImportError:
    compiler = "unknown"

try:
    from .cython_version import cython_version
except ImportError:
    cython_version = "unknown"



# this contains imports plugins that configure py.test for astropy tests.
# by importing them here in conftest.py they are discoverable by py.test
# no matter how it is invoked within the source tree.

from astropy.tests.pytest_plugins import *
from astropy.tests.pytest_plugins import pytest_addoption as astropy_pytest_addoption

# This is to figure out APLpy version, rather than using Astropy's
from . import version

import matplotlib
matplotlib.use('Agg')

try:
    packagename = os.path.basename(os.path.dirname(__file__))
    TESTED_VERSIONS[packagename] = version.version
except NameError:
    pass

# Uncomment the following line to treat all DeprecationWarnings as
# exceptions
enable_deprecations_as_exceptions()

from astropy.tests.helper import pytest


def pytest_addoption(parser):
    parser.addoption('--generate-images-path',
                     help="directory to generate reference images in",
                     action='store')
    return astropy_pytest_addoption(parser)


@pytest.fixture
def generate(request):
    return request.config.getoption("--generate-images-path")

# Add astropy to test header information and remove unused packages.

try:
    PYTEST_HEADER_MODULES['Astropy'] = 'astropy'
    PYTEST_HEADER_MODULES['pyregion'] = 'pyregion'
    PYTEST_HEADER_MODULES['PyAVM'] = 'PyAVM'
    PYTEST_HEADER_MODULES['montage-wrapper'] = 'montage-wrapper'
    del PYTEST_HEADER_MODULES['h5py']
except NameError:
    pass
